==> all-in-one-sidebar_0.7.6.orig.tar.gz: all-in-one-sidebar-0.7.6/defaults/preferences/aios.js <==
// M I S C
pref("extensions.{097d3191-e6fa-4728-9826-b533d755359d}.description", "chrome://aios/locale/lib.properties");
pref("extensions.aios.changelog", "");
pref("extensions.aios.infotips", true);
pref("extensions.aios.vbuttons", true);
pref("extensions.hideInstallButton", false);


// G E N E R A L
pref("extensions.aios.gen.orient", 1);
pref("extensions.aios.collapse", true);
pref("extensions.aios.rightclick", false);

pref("extensions.aios.gen.width.minVal", 150);
pref("extensions.aios.gen.width.minUnit", "px");

pref("extensions.aios.gen.width.defVal", 250);
pref("extensions.aios.gen.width.defUnit", "px");

pref("extensions.aios.gen.width.maxVal", 400);
pref("extensions.aios.gen.width.maxUnit", "px");

pref("extensions.aios.gen.init", "rem");
pref("extensions.aios.gen.toolbar.init", 2);
pref("extensions.aios.gen.switch.init", 2);

pref("extensions.aios.gen.open.init", "rem");

pref("extensions.aios.gen.switch.autoshow", false);
pref("extensions.aios.gen.switch.onlymax", false);
pref("extensions.aios.gen.switch.delay", 500);
pref("extensions.aios.gen.switch.hidemethod", 1);
pref("extensions.aios.gen.switch.width", 6);
pref("extensions.aios.gen.switch.twidth", 2);
pref("extensions.aios.gen.switch.thin", false);
pref("extensions.aios.gen.switch.thinmax", false);
pref("extensions.aios.gen.switch.drag", true);

pref("extensions.aios.cmode.key", 2);
pref("extensions.aios.cmode.switch", 2);
pref("extensions.aios.cmode.tbb", 2);
pref("extensions.aios.cmode.close", 1);

pref("extensions.aios.fs.sidebar", true);
pref("extensions.aios.fs.toolbar", true);
pref("extensions.aios.fs.switch", false);
pref("extensions.aios.fs.restore", true);


// P A N E L S
pref("extensions.aios.dm.sidebar", true);
pref("extensions.aios.dm.layout", true);
pref("extensions.aios.dm.layoutall", false);
pref("extensions.aios.dm.colors", true);
pref("extensions.aios.dm.sort", false);
pref("extensions.aios.dm.slim", true);
pref("extensions.aios.dm.count", true);
pref("extensions.aios.dm.tools", true);

pref("extensions.aios.em.sidebar", true);
pref("extensions.aios.em.layout", true);
pref("extensions.aios.em.layoutall", false);
pref("extensions.aios.em.colors", true);
pref("extensions.aios.em.slim", true);
pref("extensions.aios.em.count", true);
pref("extensions.aios.em.tools", true);
pref("extensions.aios.em.link", true);
pref("extensions.aios.em.custom", "");

pref("extensions.aios.bm.sidebar", true);
pref("extensions.aios.bm.tools", true);
pref("extensions.aios.hi.sidebar", true);
pref("extensions.aios.hi.tools", true);
pref("extensions.aios.mp.sidebar", true);
pref("extensions.aios.pi.sidebar", true);
pref("extensions.aios.pi.layout", true);
pref("extensions.aios.pi.layoutall", false);

pref("extensions.aios.ps.sidebar", false);
pref("extensions.aios.co.sidebar", true);
pref("extensions.aios.co.layout", true);
pref("extensions.aios.co.layoutall", false);
pref("extensions.aios.co.colors", true);
pref("extensions.aios.co.slim", true);
pref("extensions.aios.do.sidebar", false);


// M E N U S
pref("extensions.aios.menus.sidebar.entrydeac", true);
pref("extensions.aios.menus.sidebar.entries", true);
pref("extensions.aios.menus.sidebar.icons", true);
pref("extensions.aios.menus.sidebar.paneltab1", false);
pref("extensions.aios.menus.sidebar.paneltab2", false);
pref("extensions.aios.menus.sidebar.showhide", true);
pref("extensions.aios.menus.sidebar.prefs", true);

pref("extensions.aios.menus.context.entries", false);
pref("extensions.aios.menus.context.icons", true);
pref("extensions.aios.menus.context.panels", true);

pref("extensions.aios.menus.tools.entries", false);
pref("extensions.aios.menus.tools.icons", true);
pref("extensions.aios.menus.tools.prefs", true);


// S H O R T C U T S - Copyright (c) 2004, 2005 Dorando
pref("extensions.aios.keyconf.devmode", false);
pref("extensions.aios.keyconf.nicenames.reverse_order", false);
pref("extensions.aios.keyconf.profile", "main");
pref("extensions.aios.keyconf.warnOnClose", false);
pref("extensions.aios.keyconf.warnOnDuplicate", true);


// M I S C E L L A N E O U S
pref("extensions.aios.paneltab.reverse", false);
pref("extensions.aios.paneltab.bm", false);
pref("extensions.aios.tbx.tabbar", false);
pref("extensions.aios.tbx.statusbar", false);

==> all-in-one-sidebar_0.7.10.orig.tar.gz: all-in-one-sidebar-0.7.10/defaults/preferences/aios.js <==
// M I S C
pref("extensions.{097d3191-e6fa-4728-9826-b533d755359d}.description", "chrome://aios/locale/lib.properties");
pref("extensions.aios.changelog", "");
pref("extensions.aios.infotips", true);
pref("extensions.aios.vbuttons", true);
pref("extensions.hideInstallButton", false);
pref("browser.download.manager.showWhenStarting", false);
pref("browser.download.manager.closeWhenDone", false);


// G E N E R A L
pref("extensions.aios.gen.orient", 1);
pref("extensions.aios.collapse", true);
pref("extensions.aios.rightclick", false);

pref("extensions.aios.gen.width.minVal", 200);
pref("extensions.aios.gen.width.minUnit", "px");

pref("extensions.aios.gen.width.defVal", 260);
pref("extensions.aios.gen.width.defUnit", "px");

pref("extensions.aios.gen.width.maxVal", 600);
pref("extensions.aios.gen.width.maxUnit", "px");

pref("extensions.aios.gen.init", "rem");
pref("extensions.aios.gen.toolbar.init", 2);
pref("extensions.aios.gen.switch.init", 2);

pref("extensions.aios.gen.open.init", "rem");

pref("extensions.aios.gen.switch.autoshow", false);
pref("extensions.aios.gen.switch.onlymax", false);
pref("extensions.aios.gen.switch.delay", 500);
pref("extensions.aios.gen.switch.hidemethod", 1);
pref("extensions.aios.gen.switch.width", 6);
pref("extensions.aios.gen.switch.twidth", 2);
pref("extensions.aios.gen.switch.thin", false);
pref("extensions.aios.gen.switch.thinmax", false);
pref("extensions.aios.gen.switch.drag", true);

pref("extensions.aios.cmode.key", 2);
pref("extensions.aios.cmode.switch", 2);
pref("extensions.aios.cmode.tbb", 2);
pref("extensions.aios.cmode.close", 1);

pref("extensions.aios.fs.sidebar", true);
pref("extensions.aios.fs.toolbar", true);
pref("extensions.aios.fs.switch", false);
pref("extensions.aios.fs.restore", true);


// P A N E L S
pref("extensions.aios.dm.sidebar", true);
pref("extensions.aios.dm.layout", true);
pref("extensions.aios.dm.layoutall", false);
pref("extensions.aios.dm.autoopen", true);
pref("extensions.aios.dm.autoclose", false);
pref("extensions.aios.dm.colors", true);
pref("extensions.aios.dm.slim", true);
pref("extensions.aios.dm.count", true);

pref("extensions.aios.em.sidebar", true);
pref("extensions.aios.em.layout", true);
pref("extensions.aios.em.layoutall", false);
pref("extensions.aios.em.colors", true);
pref("extensions.aios.em.slim", true);
pref("extensions.aios.em.count", true);

pref("extensions.aios.bm.sidebar", true);
pref("extensions.aios.bm.layout", true);
pref("extensions.aios.bm.layoutall", false);

pref("extensions.aios.hi.sidebar", true);
pref("extensions.aios.hi.layout", true);
pref("extensions.aios.hi.layoutall", false);

pref("extensions.aios.mp.sidebar", true);

pref("extensions.aios.pi.sidebar", true);
pref("extensions.aios.pi.layout", true);
pref("extensions.aios.pi.layoutall", false);

pref("extensions.aios.ps.sidebar", false);

pref("extensions.aios.co.sidebar", true);
pref("extensions.aios.co.layout", true);
pref("extensions.aios.co.layoutall", false);
pref("extensions.aios.co.colors", true);
pref("extensions.aios.co.slim", true);


// M E N U S
pref("extensions.aios.menus.sidebar.entrydeac", true);
pref("extensions.aios.menus.sidebar.entries", true);
pref("extensions.aios.menus.sidebar.icons", true);
pref("extensions.aios.menus.sidebar.paneltab1", false);
pref("extensions.aios.menus.sidebar.paneltab2", false);
pref("extensions.aios.menus.sidebar.showhide", true);
pref("extensions.aios.menus.sidebar.prefs", true);


// S H O R T C U T S - Copyright (c) 2004, 2005 Dorando
pref("extensions.aios.keyconf.devmode", false);
pref("extensions.aios.keyconf.nicenames.reverse_order", false);
pref("extensions.aios.keyconf.profile", "main");
pref("extensions.aios.keyconf.warnOnClose", false);
pref("extensions.aios.keyconf.warnOnDuplicate", true);


// M I S C E L L A N E O U S
pref("extensions.aios.paneltab.reverse", false);
pref("extensions.aios.paneltab.bm", false);
